use anyhow::Result;
use postgres::{PostgresUserService, PostgresProductService};
use tui::run_tui;

#[tokio::main]
async fn main() -> Result<()> {
    dotenvy::dotenv().ok();
    let pool = sqlx::PgPool::connect(&std::env::var("DATABASE_URL")?).await?;
    let user_service = PostgresUserService::new(postgres::PostgresUserRepository::new(pool.clone()));
    let product_service = PostgresProductService::new(postgres::PostgresProductRepository::new(pool));
    run_tui(user_service, product_service).await
}
